@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -393,6 +393,19 @@ public:
   virtual Event* clone () const;
 
 
+  /**
+   * Initializes the fields of this Event object to "typical" default
+   * values.
+   *
+   * The SBML Event component has slightly different aspects and
+   * default attribute values in different SBML Levels and Versions.
+   * This method sets the values to certain common defaults, based
+   * mostly on what they are in SBML Level&nbsp;2.  Specifically:
+   *
+   * @li Sets attribute "spatialDimensions" to @c 3
+   */
+  void initDefaults ();
+
   /**
    * Returns the first child element found that has the given @p id in the
    * model-wide SId namespace, or @c NULL if no such object is found.
@@ -725,6 +738,20 @@ public:
   virtual int unsetName ();
 
 
+  /**
+   * Unsets the value of the "useValuesFromTriggerTime" attribute of this Event.
+   *
+   * @copydetails doc_event_using_useValuesFromTriggerTime
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   *
+   * @copydetails doc_warning_useValuesFromTriggerTime
+   */
+  int unsetUseValuesFromTriggerTime ();
+
+
   /**
    * Unsets the Delay of this Event.
    *
@@ -1809,6 +1836,22 @@ int
 Event_unsetName (Event_t *e);
 
 
+/**
+ * Unsets the "useValuesFromTriggerTime" attribute of the given Event_t structure.
+ *
+ * @param e the Event_t structure to unset
+ *
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof Event_t
+ */
+LIBSBML_EXTERN
+int
+Event_unsetUseValuesFromTriggerTime (Event_t *e);
+
+
 /**
  * Unsets the delay of the given Event_t.
  *
