@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -406,6 +406,16 @@ public:
   int setVariable (const std::string& sid);
 
 
+  /**
+   * Unsets the attribute "variable" of this EventAssignment.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+   */
+  int unsetVariable ();
+
+
   /**
    * Sets the "math" subelement of this EventAssignment to a copy of the
    * given ASTNode.
@@ -1068,6 +1078,22 @@ int
 EventAssignment_setVariable (EventAssignment_t *ea, const char *sid);
 
 
+/**
+ * Unsets the attribute "variable" of the given EventAssignment_t structure.
+ *
+ * @param ea the EventAssignment_t to set.
+ *
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @memberof EventAssignment_t
+ */
+LIBSBML_EXTERN
+int
+EventAssignment_unsetVariable (EventAssignment_t *ea);
+
+
 /**
  * Sets the "math" subelement content of the given EventAssignment_t
  * structure to the given ASTNode_t.
