@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -369,15 +369,23 @@ public:
    * @param sid the identifier of a Species, Compartment or Parameter
    * object defined elsewhere in this Model.
    *
-   * @return integer value indicating success/failure of the
-   * function.  The possible values
-   * returned by this function are:
+   * @copydetails doc_returns_success_code
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   int setSymbol (const std::string& sid);
 
 
+  /**
+   * Unsets the "symbol" attribute value of this InitialAssignment.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+   */
+  int unsetSymbol ();
+
+
   /**
    * Sets the "math" subelement of this InitialAssignment.
    *
@@ -386,9 +394,7 @@ public:
    * @param math an AST containing the mathematical expression to
    * be used as the formula for this InitialAssignment.
    *
-   * @return integer value indicating success/failure of the
-   * function.  The possible values
-   * returned by this function are:
+   * @copydetails doc_returns_success_code
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
    */
@@ -1020,10 +1026,7 @@ InitialAssignment_isSetMath (const InitialAssignment_t *ia);
  * @param sid the identifier of a Species_t, Compartment_t or Parameter_t
  * structure defined elsewhere in this Model_t.
  *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
+ * @copydetails doc_returns_success_code
  * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
  * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
  *
@@ -1037,6 +1040,22 @@ int
 InitialAssignment_setSymbol (InitialAssignment_t *ia, const char *sid);
 
 
+/**
+ * Unsets the "symbol" attribute value of this InitialAssignment_t
+ *
+ * @param ia the InitialAssignment_t structure
+ *
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @memberof InitialAssignment_t
+ */
+LIBSBML_EXTERN
+int
+InitialAssignment_unsetSymbol (InitialAssignment_t *ia);
+
+
 /**
  * Sets the "math" subelement of this InitialAssignment_t
  *
@@ -1047,10 +1066,7 @@ InitialAssignment_setSymbol (InitialAssignment_t *ia, const char *sid);
  * @param math an ASTNode_t tree containing the mathematical expression to
  * be used as the formula for this InitialAssignment_t.
  *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
+ * @copydetails doc_returns_success_code
  * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
  * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
  *
