@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -99,7 +99,7 @@ Parameter::Parameter (SBMLNamespaces * sbmlns) :
     throw SBMLConstructorException(getElementName(), sbmlns);
   }
 
-  loadPlugins(sbmlns);
+   loadPlugins(sbmlns);
 
   // if level 3 values have no defaults
   if (sbmlns->getLevel() == 3)
@@ -114,6 +114,30 @@ Parameter::Parameter (SBMLNamespaces * sbmlns) :
 }
 
 
+/** @cond doxygenLibsbmlInternal */
+Parameter::Parameter (SBMLNamespaces * sbmlns, bool isLocal) :
+   SBase      ( sbmlns   )
+ , mId        ( ""       )
+ , mName      ( ""       )
+ , mValue     ( 0.0      )
+ , mUnits     ( ""       )
+ , mConstant  ( true     )
+ , mIsSetValue( false    )
+ , mIsSetConstant (false )
+ , mExplicitlySetConstant ( false )
+ , mCalculatingUnits (false)
+{
+  if (!hasValidLevelVersionNamespaceCombination())
+  {
+    throw SBMLConstructorException(getElementName(), sbmlns);
+  }
+
+  // we are creating a L3 LocalParameter so L3 defaults apply
+  mValue = numeric_limits<double>::quiet_NaN();
+}
+/** @endcond */
+
+
 /*
  * Destroys this Parameter.
  */
@@ -206,11 +230,9 @@ Parameter::clone () const
 void
 Parameter::initDefaults ()
 {
-  //// level 3 has no defaults
-  //if (getLevel() < 3)
-  //{
-    setConstant(true);
-  //}
+  setConstant(true);
+  // not explicitly set
+  mExplicitlySetConstant = false;
 }
 
 
@@ -473,6 +495,31 @@ Parameter::unsetName ()
 }
 
 
+int
+Parameter::unsetConstant ()
+{
+  if ( getLevel() < 2 )
+  {
+    mConstant = false;
+    return LIBSBML_UNEXPECTED_ATTRIBUTE;
+  }
+  else if (getLevel() == 2)
+  {
+    // reset default
+    mConstant = true;
+    mExplicitlySetConstant = false;
+    mIsSetConstant = true;
+    return LIBSBML_UNEXPECTED_ATTRIBUTE;
+  }
+  else
+  {
+    mIsSetConstant = false;
+    mExplicitlySetConstant = false;
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+}
+
+
 /*
  * Unsets the value of this Parameter.
  *
@@ -557,10 +604,24 @@ Parameter::getDerivedUnitDefinition()
    * OR the object is not yet a child of a model
    */
 
+  if (m == NULL)
+  {
+    return NULL;
+  }
+  else
+  {
+  /* if we have a model calculate all units */
+    if (!m->isPopulatedListFormulaUnitsData())
+    {
+      m->populateListFormulaUnitsData();
+    }
+  }
+
   /* need to distinguish between a global and local parameter
-  * for a global parameter a unit definition will have been created
-  * for a local parameter need to create one based on the units field
-  */
+   * in order to determine the id that will be used
+   * in the ListFormulaUnitsData
+   */
+    
   bool globalParameter = false;
   SBase *parent  = getParentSBMLObject();
   SBase *pparent = (parent) ? parent->getParentSBMLObject() : NULL; 
@@ -569,72 +630,35 @@ Parameter::getDerivedUnitDefinition()
     globalParameter = true;
   }
 
-  /* if we have a model calculate all units */
-  if (m != NULL)
-  {
-    if (!m->isPopulatedListFormulaUnitsData())
-    {
-      m->populateListFormulaUnitsData();
-    }
-  }
-
   std::string id = this->getId();
+  int typecode = getTypeCode();
+
+  if (globalParameter == false)
+  {
+    // need the id of the reaction
+    Reaction * r = static_cast<Reaction*>(getAncestorOfType(SBML_REACTION));
+    
+    // should not get NULL here but just in case
+    if (r == NULL) return NULL;
+    
+    id = getId() + '_' + r->getId();
+    typecode = SBML_LOCAL_PARAMETER;
+  }
 
   if (calculate == true)
   {
-    if (m != NULL)
-    {
-      derivedUD = inferUnits(m, globalParameter);
-    }
+    derivedUD = inferUnits(m, globalParameter);
   }
   else
   {
     /* here we do not want to try to infer the unit from any formula
     * we just use what is given
     */
-    if (m != NULL)
+    if (m->getFormulaUnitsData(id, typecode) != NULL)
     {
-      if (globalParameter)
-      {
-        /* we are global parameter so units might have been set
-         * if not return NULL
-         */
-        if (m->getFormulaUnitsData(id, getTypeCode()) != NULL)
-        {
-          derivedUD = new UnitDefinition(*(m->getFormulaUnitsData(id, 
-                              getTypeCode())->getUnitDefinition()));
-        }
-      }
-      else
-      {
-        std::string units = getUnits();
-        if (units.empty() == false)
-        {
-          if (UnitKind_isValidUnitKindString(units.c_str(), 
-                                getLevel(), getVersion()))
-          {
-            Unit * unit = new Unit(getSBMLNamespaces());
-            unit->setKind(UnitKind_forName(units.c_str()));
-            unit->initDefaults();
-            derivedUD   = new UnitDefinition(getSBMLNamespaces());
+      // we already have the ud in memory return it
 
-            derivedUD->addUnit(unit);
-
-            delete unit;
-          }
-          else
-          {
-            /* must be a unit definition */
-            derivedUD = new UnitDefinition(*(m->getUnitDefinition(units)));
-          }
-        }
-        else
-        {
-          // here we have none but for consistency return a unitDefinition
-          // with no units
-          derivedUD = new UnitDefinition(getSBMLNamespaces());
-        }
-      }
+      derivedUD = m->getFormulaUnitsData(id, typecode)->getUnitDefinition();
     }
   }
 
@@ -808,7 +832,8 @@ Parameter::readL1Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("name", level, version, "<parameter>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // value: double  { use="required" }  (L1v2)
@@ -833,7 +858,7 @@ Parameter::readL1Attributes (const XMLAttributes& attributes)
   }
   if (!SyntaxChecker::isValidInternalUnitSId(mUnits))
   {
-    logError(InvalidUnitIdSyntax);
+    logError(InvalidUnitIdSyntax, getLevel(), getVersion(), "The units attribute '" + mUnits + "' does not conform to the syntax.");
   }
 }
 /** @endcond */
@@ -860,7 +885,8 @@ Parameter::readL2Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<parameter>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // value: double  { use="optional" }  (L1v2->)
@@ -877,7 +903,7 @@ Parameter::readL2Attributes (const XMLAttributes& attributes)
   }
   if (!SyntaxChecker::isValidInternalUnitSId(mUnits))
   {
-    logError(InvalidUnitIdSyntax);
+    logError(InvalidUnitIdSyntax, getLevel(), getVersion(), "The units attribute '" + mUnits + "' does not conform to the syntax.");
   }
 
   //
@@ -935,8 +961,13 @@ Parameter::readL3Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<parameter>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
+  string elplusid = "<" + getElementName() + ">";
+  if (!mId.empty()) {
+    elplusid += " with the id '" + mId + "'";
+  }
   //
   // value: double  { use="optional" }  (L1v2->)
   //
@@ -952,7 +983,9 @@ Parameter::readL3Attributes (const XMLAttributes& attributes)
   }
   if (!SyntaxChecker::isValidInternalUnitSId(mUnits))
   {
-    logError(InvalidUnitIdSyntax);
+    logError(InvalidUnitIdSyntax, level, version, "The " + elplusid + 
+      " has a substanceUnits with a value of '" + mUnits 
+      + "' which does not conform .");
   }
 
   //
@@ -967,7 +1000,8 @@ Parameter::readL3Attributes (const XMLAttributes& attributes)
     if (!mIsSetConstant)
     {
       logError(AllowedAttributesOnParameter, level, version, 
-        "The required attribute 'constant' is missing.");
+        "The required attribute 'constant' is missing from the "
+             + elplusid + ".");
     }
   }
 }
@@ -1390,6 +1424,7 @@ Parameter::inferUnitsFromEvent(Event * e, UnitFormulaFormatter *uff, Model *m)
       u->setKind(UNIT_KIND_DIMENSIONLESS);
 
       derivedUD = uff->inferUnitDefinition(dim, math, id);
+      delete dim;
       //found = true;
     }
   }              
@@ -1851,6 +1886,17 @@ Parameter_unsetName (Parameter_t *p)
 }
 
 
+LIBSBML_EXTERN
+int
+Parameter_unsetConstant (Parameter_t *c)
+{
+  if (c != NULL)
+    return c->unsetConstant();
+  else
+    return LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 int
 Parameter_unsetValue (Parameter_t *p)
