@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -1053,6 +1053,20 @@ public:
   virtual int unsetName ();
 
 
+  /**
+   * Unsets the value of the "constant" attribute of this Species object.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   *
+   * @see isSetConstant()
+   * @see setConstant(@if java String@endif)
+   * @see getConstant()
+   */
+  int unsetConstant ();
+
+
   /**
    * Unsets the "speciesType" attribute value of this Species object.
    *
@@ -1150,6 +1164,36 @@ public:
   int unsetConversionFactor ();
 
 
+  /**
+   * Unsets the "compartment" attribute value of this Species object.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  int unsetCompartment ();
+
+
+  /**
+   * Unsets the "boundaryCondition" attribute value of this Species object.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  int unsetBoundaryCondition ();
+
+
+  /**
+   * Unsets the "hasOnlySubstanceUnits" attribute value of this Species object.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  int unsetHasOnlySubstanceUnits ();
+
+
   /**
    * Constructs and returns a UnitDefinition that corresponds to the units
    * of this Species' amount or concentration.
@@ -2535,6 +2579,24 @@ int
 Species_unsetName (Species_t *s);
 
 
+/**
+ * Unsets the value of the "constant" attribute of the given Species_t
+ * structure.
+ *
+ * @param c the Species_t structure.
+ *
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
+ *
+ * @memberof Species_t
+ */
+LIBSBML_EXTERN
+int
+Species_unsetConstant (Species_t *c);
+
+
 /**
  * Unsets the "speciesType" attribute of the given Species_t structure.
  *
@@ -2684,6 +2746,54 @@ int
 Species_unsetConversionFactor (Species_t *s);
 
 
+/**
+ * Unsets the "compartment" attribute of the given Species_t structure.
+ *
+ * @param s the Species_t structure whose attribute is to be unset.
+ *
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof Species_t
+ */
+LIBSBML_EXTERN
+int
+Species_unsetCompartment (Species_t *s);
+
+
+/**
+ * Unsets the "boundaryCondition" attribute of the given Species_t structure.
+ *
+ * @param s the Species_t structure whose attribute is to be unset.
+ *
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof Species_t
+ */
+LIBSBML_EXTERN
+int
+Species_unsetBoundaryCondition (Species_t *s);
+
+
+/**
+ * Unsets the "hasOnlySubstanceUnits" attribute of the given Species_t structure.
+ *
+ * @param s the Species_t structure whose attribute is to be unset.
+ *
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ *
+ * @memberof Species_t
+ */
+LIBSBML_EXTERN
+int
+Species_unsetHasOnlySubstanceUnits (Species_t *s);
+
+
 /**
  * Constructs and returns a UnitDefinition_t structure that expresses 
  * the units of this Species_t structure.
