@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -357,6 +357,38 @@ public:
    */
   int setPersistent (bool persistent);
 
+
+  /**
+   * (SBML Level&nbsp;3 only) Unsets the "initialValue" attribute of this 
+   * Trigger instance.
+   *
+   * @param initialValue a boolean representing the initialValue to be set.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_UNEXPECTED_ATTRIBUTE, OperationReturnValues_t}
+   * 
+   * @note The attribute "initialValue" is available in SBML Level&nbsp;3
+   * Version&nbsp;1 Core, but is not present in lower Levels of SBML.
+   */
+  int unsetInitialValue ();
+
+
+  /**
+   * (SBML Level&nbsp;3 only) Unsets the "persistent" attribute of this 
+   * Trigger instance.
+   *
+   * @param persistent a boolean representing the persistent value to be set.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_UNEXPECTED_ATTRIBUTE, OperationReturnValues_t}
+   * 
+   * @note The attribute "persistent" is available in SBML Level&nbsp;3
+   * Version&nbsp;1 Core, but is not present in lower Levels of SBML.
+   */
+  int unsetPersistent ();
+
 #if (0)
   /** @cond doxygenLibsbmlInternal */
 
@@ -788,6 +820,38 @@ int
 Trigger_setPersistent (Trigger_t *t, int persistent);
 
 
+/**
+ * Unsets the "initialValue" attribute of this Trigger_t instance.
+ *
+ * @param t the Trigger_t structure
+ *
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_UNEXPECTED_ATTRIBUTE, OperationReturnValues_t}
+ *
+ * @memberof Trigger_t
+ */
+LIBSBML_EXTERN
+int
+Trigger_unsetInitialValue (Trigger_t *t);
+
+
+/**
+ * Unsets the "persistent" attribute of this Trigger_t instance.
+ *
+ * @param t the Trigger_t structure
+ *
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_UNEXPECTED_ATTRIBUTE, OperationReturnValues_t}
+ *
+ * @memberof Trigger_t
+ */
+LIBSBML_EXTERN
+int
+Trigger_unsetPersistent (Trigger_t *t);
+
+
 /**
   * Predicate returning @c true or @c false depending on whether
   * all the required attributes for this Trigger_t structure
