@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -1061,9 +1061,25 @@ public:
   void resetModifiedFlags();
    
   bool hasRequiredAttributes() const;
+
   
   /** @endcond */
+  /** @cond doxygenLibsbmlInternal */
+  unsigned int getNumNestedCVTerms() const;
 
+  const CVTerm * getNestedCVTerm(unsigned int n) const;
+
+  CVTerm * getNestedCVTerm(unsigned int n);
+
+  List* getListNestedCVTerms();
+
+  const List* getListNestedCVTerms() const;
+
+  int addNestedCVTerm(const CVTerm* term);
+
+  CVTerm* removeNestedCVTerm(unsigned int n);
+
+  /** @endcond */
 
 protected:
   /** @cond doxygenLibsbmlInternal */
@@ -1076,6 +1092,11 @@ protected:
 
   bool mHasBeenModified;
 
+  List* mNestedCVTerms;
+
+  void setHasBeenModifiedFlag();
+
+  friend class SBase;
   /** @endcond */
 };
 
@@ -1488,6 +1509,28 @@ LIBSBML_EXTERN
 BiolQualifierType_t 
 BiolQualifierType_fromString(const char* s);
 
+/** @cond doxygenLibsbmlInternal */
+LIBSBML_EXTERN
+unsigned int 
+CVTerm_getNumNestedCVTerms(const CVTerm_t* cvt);
+
+LIBSBML_EXTERN
+const CVTerm_t * 
+CVTerm_getNestedCVTerm(const CVTerm_t* cvt, unsigned int n);
+
+LIBSBML_EXTERN
+int 
+CVTerm_addNestedCVTerm(CVTerm_t* cvt, const CVTerm_t* term);
+
+LIBSBML_EXTERN
+CVTerm_t * 
+CVTerm_removeNestedCVTerm(CVTerm_t* cvt, unsigned int n);
+
+LIBSBML_EXTERN
+const List_t * 
+CVTerm_getListNestedCVTerms(const CVTerm_t* cvt);
+
+/** @endcond */
 
 END_C_DECLS
 LIBSBML_CPP_NAMESPACE_END
