@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -49,6 +49,8 @@
  * SBML document; consequently, the packages in use are also communicated by
  * the values of the SBML namespaces set on a ConversionProperties object.
  *
+ * @copydetails doc_section_using_sbml_converters
+ *
  * @see ConversionOption
  * @see SBMLNamespaces
  */
@@ -719,10 +721,13 @@ ConversionProperties_addOptionWithKey(ConversionProperties_t* cp, const char* ke
  * @param cp the conversion properties
  * @param key the key for the option to remove
  *
+ * @return the removed conversion option (needs to be freed by the caller), 
+ * or NULL, if no option with the given key exists
+ * 
  * @memberof ConversionProperties_t
  */
 LIBSBML_EXTERN
-void
+ConversionOption_t*
 ConversionProperties_removeOption(ConversionProperties_t* cp, const char* key);
 
 
