@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -110,12 +110,24 @@ ConversionProperties
 SBMLLevelVersionConverter::getDefaultProperties() const
 {
   static ConversionProperties prop;
-  prop.setTargetNamespaces(new SBMLNamespaces()); // default namespaces
-  prop.addOption("strict", true,
-                 "Whether validity should be strictly preserved");
-  prop.addOption("setLevelAndVersion", true, 
-                 "Convert the model to a given Level and Version of SBML");
-  return prop;
+  static bool init = false;
+
+  if (init) 
+  {
+    return prop;
+  }
+  else
+  {
+    SBMLNamespaces * sbmlns = new SBMLNamespaces(); // default namespaces
+    prop.setTargetNamespaces(sbmlns); // this gets cloned
+    prop.addOption("strict", true,
+                   "Whether validity should be strictly preserved");
+    prop.addOption("setLevelAndVersion", true, 
+                   "Convert the model to a given Level and Version of SBML");
+    delete sbmlns;
+    init = true;
+    return prop;
+  }
 }
 
 
@@ -339,7 +351,7 @@ SBMLLevelVersionConverter::convert()
       {
         /* now we want to mDocument->check whether the resulting model is valid
          */
-        mDocument->validateSBML();
+        validateConvertedDocument();
         unsigned int errors = 
            mDocument->getErrorLog()->getNumFailsWithSeverity(LIBSBML_SEV_ERROR);
         if (errors > 0)
@@ -440,6 +452,12 @@ SBMLLevelVersionConverter::performConversion(bool strict, bool strictUnits,
           doConversion = true;
         }
         break;
+      case 5:
+        if (!conversion_errors(mDocument->checkL2v4Compatibility()))
+        {
+          doConversion = true;
+        }
+        break;
       default:
         mDocument->getErrorLog()->logError(InvalidTargetLevelVersion, currentLevel, currentVersion);
         break;
@@ -669,6 +687,19 @@ SBMLLevelVersionConverter::performConversion(bool strict, bool strictUnits,
           }
         }
         break;
+      case 5:
+        if (!conversion_errors(mDocument->checkL2v4Compatibility()))
+        {
+          doConversion = true;
+          // look for duplicate top targetLevel annotations
+          for (i = 0; i < mDocument->getErrorLog()->getNumErrors(); i++)
+          {
+            if (mDocument->getErrorLog()->getError(i)->getErrorId() 
+                            == DuplicateAnnotationInvalidInL2v4)
+              duplicateAnn = true;
+          }
+        }
+        break;
       default:
         mDocument->getErrorLog()->logError(InvalidTargetLevelVersion, currentLevel, currentVersion);
         break;
@@ -722,7 +753,7 @@ SBMLLevelVersionConverter::performConversion(bool strict, bool strictUnits,
         }
         currentModel->convertParametersToLocals(targetLevel, targetVersion);
         mDocument->updateSBMLNamespace("core", targetLevel, targetVersion);
-        currentModel->convertL2ToL3();
+        currentModel->convertL2ToL3(strict);
         conversion = true;
       }
       break;
@@ -765,7 +796,7 @@ SBMLLevelVersionConverter::performConversion(bool strict, bool strictUnits,
             mDocument->expandFunctionDefinitions();
             mDocument->expandInitialAssignments();
             mDocument->updateSBMLNamespace("core", targetLevel, targetVersion);
-            currentModel->convertL3ToL1();
+            currentModel->convertL3ToL1(strict);
             conversion = true;
           }
         }
@@ -877,6 +908,12 @@ SBMLLevelVersionConverter::performConversion(bool strict, bool strictUnits,
           doConversion = true;
         }
         break;
+      case 5:
+        if (!conversion_errors(mDocument->checkL2v4Compatibility(), strictUnits))
+        {
+          doConversion = true;
+        }
+        break;
       default:
         mDocument->getErrorLog()->logError(InvalidTargetLevelVersion, currentLevel, currentVersion);
         break;
@@ -1046,7 +1083,24 @@ SBMLLevelVersionConverter::hasStrictSBO()
 
 /** @cond doxygenIgnored */
 
+unsigned int
+SBMLLevelVersionConverter::validateConvertedDocument()
+{
+  // force a read
+  std::string sbml = writeSBMLToStdString(mDocument);
+  SBMLDocument *tempdoc = readSBMLFromString(sbml.c_str());
+  unsigned int nerrors = tempdoc->getErrorLog()->getNumErrors();
+  for (unsigned int i = 0; i < nerrors; i++)
+  {
+    const SBMLError * error = tempdoc->getErrorLog()->getError(i);
+    mDocument->getErrorLog()->add(*(error));
+  }
+  delete tempdoc;
 
+  nerrors += mDocument->checkConsistency();
+
+  return nerrors;
+}
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
