@@ -11,7 +11,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -36,6 +36,8 @@
  *
  * @class ASTBasePlugin
  * @sbmlbrief{core} Base class for extensions that plug into AST classes.
+ *
+ * @htmlinclude not-sbml-warning.html
  */
 
 #ifndef ASTBasePlugin_h
@@ -224,10 +226,7 @@ public:
    * Version 1 Core must set the namespace to 
    * "http://www.sbml.org/sbml/level3/version1/layout/version1/"
    *
-   * @return integer value indicating success/failure of the
-   * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif@~ The possible values
-   * returned by this function are:
+   * @copydetails doc_returns_success_code
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
@@ -286,7 +285,7 @@ public:
 
   virtual int removeChild(unsigned int n);
 
-  virtual int replaceChild(unsigned int n, ASTBase* newChild);
+  virtual int replaceChild(unsigned int n, ASTBase* newChild, bool delreplaced);
 
   virtual int swapChildren(ASTFunction* that);
 
@@ -424,7 +423,7 @@ protected:
   // Parent ASTNode object to which this plugin object
   // connected.
   //
-  ASTBase                *mParent;
+  ASTBase                *mParentASTNode;
 
   //
   // XML namespace of corresponding package extension
