@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -534,7 +534,7 @@ Model* CompModelPlugin::flattenModel() const
       //Strip the ports from the submodel, as we no longer need them.
       while (submodplug->getNumPorts() > 0) 
       {
-        submodplug->removePort(0);
+        delete submodplug->removePort(0);
       }
     }
     success = flat->appendFrom(submodel);
@@ -644,8 +644,12 @@ CompModelPlugin::appendFrom(const Model* model)
   const CompModelPlugin* modplug = 
     static_cast<const CompModelPlugin*>(model->getPlugin(getPrefix()));
   
-  if (modplug==NULL) 
-    return LIBSBML_INVALID_OBJECT;
+  // absence of a plugin is not an error
+  if (modplug==NULL)
+  {
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+
 
   Model* parent = static_cast<Model*>(getParentSBMLObject());
 
@@ -693,14 +697,17 @@ CompModelPlugin::instantiateSubmodels()
       return LIBSBML_OPERATION_FAILED;
     }
     
-    // if we have a transformer specified, then we need to propagate it, so it can
-    // be used
-    if (isSetTransformer())
-    {
-      CompModelPlugin* other = dynamic_cast<CompModelPlugin*>(submodinst->getPlugin("comp"));
-      if (other != NULL)
-        other->setTransformer(getTransformer());
-    }
+    //// if we have a transformer specified, then we need to propagate it, so it can
+    //// be used
+
+    // this needs to happen in Submodel:instantiate
+
+    //if (isSetTransformer())
+    //{
+    //  CompModelPlugin* other = dynamic_cast<CompModelPlugin*>(submodinst->getPlugin("comp"));
+    //  if (other != NULL)
+    //    other->setTransformer(getTransformer());
+    //}
   }
 
   // Next, recursively find all the targets of SBaseRef elements 
@@ -775,6 +782,7 @@ int CompModelPlugin::saveAllReferencedElements(set<SBase*> uniqueRefs, set<SBase
   if (model->isSetId()) {
     modname = "the model '" + model->getId() + "'";
   }
+  set<SBase*> todelete;
   for (unsigned int el=0; el<allElements->getSize(); el++) {
     SBase* element = static_cast<SBase*>(allElements->get(el));
     int type = element->getTypeCode();
@@ -808,8 +816,6 @@ int CompModelPlugin::saveAllReferencedElements(set<SBase*> uniqueRefs, set<SBase
                      CompIdRefMayReferenceUnknownPackage, getPackageVersion(), 
                      getLevel(), getVersion(), fullmsg, element->getLine(), 
                      element->getColumn(), LIBSBML_SEV_WARNING);
-                    element->removeFromParentAndDelete();
-                    continue;
                 }
                 else if ( lasterr->getErrorId() == CompMetaIdRefMustReferenceObject)
                 {
@@ -823,27 +829,11 @@ int CompModelPlugin::saveAllReferencedElements(set<SBase*> uniqueRefs, set<SBase
                      CompMetaIdRefMayReferenceUnknownPkg, getPackageVersion(), 
                      getLevel(), getVersion(), fullmsg, element->getLine(), 
                      element->getColumn(), LIBSBML_SEV_WARNING);
-                    element->removeFromParentAndDelete();
-                    continue;
-                }
-                else if (lasterr->getErrorId() == 
-                                  CompIdRefMayReferenceUnknownPackage)
-                {
-                  element->removeFromParentAndDelete();
-                  continue;
-                }
-                else if (lasterr->getErrorId() == 
-                                  CompMetaIdRefMayReferenceUnknownPkg)
-                {
-                  element->removeFromParentAndDelete();
-                  continue;
                 }
               }
-              else 
-              {
-                delete allElements;
-                return ret;
-              }
+              //Whether or not we could figure out the error, we can always still continue flattening.
+              todelete.insert(element);
+              continue;
             }
             else {
               delete allElements;
@@ -910,6 +900,9 @@ int CompModelPlugin::saveAllReferencedElements(set<SBase*> uniqueRefs, set<SBase
     }
   }
 
+  for(set<SBase*>::iterator el=todelete.begin(); el != todelete.end(); el++) {
+    (*el)->removeFromParentAndDelete();
+  }
   delete allElements;
 
   //Now call saveAllReferencedElements for all instantiated submodels.
